package com.ruoyi.system.mapper;

import com.ruoyi.system.domain.GtgsywPrintList;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * @Author: Abeiv
 * @Description:
 * @Date: 2019-12-10 15:36
 */
public interface GtgsywPrintListMapper {
    int deleteByPrimaryKey(Integer id);

    int insert(GtgsywPrintList record);

    int insertSelective(GtgsywPrintList record);

    GtgsywPrintList selectByPrimaryKey(String id);

    List<GtgsywPrintList> selectByCard(String jycard);

    int updateByPrimaryKeySelective(GtgsywPrintList record);

    int updateByPrimaryKey(GtgsywPrintList record);

    //分页查询
    List<GtgsywPrintList> selectAll(GtgsywPrintList gtgsywPrintList);

    /**
     * 批量删除
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    int deleteGtgsywByIds(String[] ids);


    GtgsywPrintList selectByCB(@Param("jycard") String jycard, @Param("Bsid")String Bsid);

    String selectByAppNo(String appNo);
    //分页查询
    List<GtgsywPrintList> selectByIsPrint(GtgsywPrintList gtgsywPrintList);
}
